% This demo shows how to use DCAT (Data Classification and Analysis Tool)
% using a simple artificial example. There are used classifiers SVM,
% Bayesian network, Discriminant analysis, k-Nearest Neighbor, decision
% trees, GMM and ANN. There is also used a score fusion technique based on
% ANN. There is used CMIM fetaure selection (filtering method) with a
% consequent MRMR implemented as a wrapping feature selection method.

%% Initial clean up
close all;
clear all;
clc;

%% Paths and variables
addpath('toolbox');

% Set the split ratio of training/testing data and method of split
sett.split_ratio = 0.75;
sett.split_method = 'random';

% Use the z-score normalization
sett.norm = 1;

% Number of validations
sett.rnd = 3;

% Filtering fetaure selection method
sett.fsel1_method = 'cmim';
sett.fsel1_num_sel = 20;

% Wrapping feature selection method
sett.fsel2_method = 'mrmr';
sett.fsel2_max_num = [];
sett.fsel2_term = [];
sett.fsel2_rnd = 5;

% Select the label of interest
sett.sel_label = 'label1';

% Path to the output *.xlsx file with results
sett.out = 'res_demo.xlsx';

% Classifiers' settings
sett.cls(1).name = 'svm';
sett.cls(1).kernel = 'linear';
sett.cls(1).descr = 'SVM (linear)';

sett.cls(2).name = 'bayes';
sett.cls(2).distribution = 'normal';
sett.cls(2).prior = 'uniform';

sett.cls(3).name = 'da';
sett.cls(3).discrimType = 'linear';
sett.cls(3).prior = 'uniform';

sett.cls(4).name = 'knn';
sett.cls(4).K = 1;
sett.cls(4).Distance = 'euclidean';

sett.cls(5).name = 'tree';
sett.cls(5).SplitCriterion = 'deviance';
sett.cls(5).prior = 'uniform';

sett.cls(6).name = 'gmm';
sett.cls(6).k = 1;

sett.cls(7).name = 'ann';

sett.fus(1).name = 'ann';

% Prepare the artificial data
data = randn(1e3,1e3);
labels = [ones(500,1); ones(500,1)*2];
ind = [52 98 145 600 785 835 911];
data(:,ind) = data(:,ind)+repmat(labels,1,length(ind)).*1.0;
data = data.';

table = cell(size(data,1)+2, size(data,2)+1);
table(3:end,2:end) = num2cell(data);
table(3:end,1) = num2cell((1:size(table,1)-2).');
table(2,2:501) = {'label1'};
table(2,502:1001) = {'label2'};

table(3:end,1) = cellfun(@(x) ['f' num2str(x)], table(3:end,1), ...
    'UniformOutput', false);

%% Convert the NDAT table
% This is used onlz when the data are imported from the NDAT (Neurologicla
% Disorder Analysis Tool). If zou have directly teh data and labels, zou
% can proceed to function split_data.
[data, labels, sett.labels_descr, sett.features_descr] = ...
    convert_ndat_table(table);

%% Do the classification
[d_train, d_test, l_train, l_test] = split_data(data, labels, ...
        sett.split_ratio, sett.split_method);
    
proc = dcat(sett, d_train, l_train);
% proc = dcat(sett, d_train, l_train, d_test, l_test);
evaluation_overall(proc, sett);