function [label, scores] = GMMclassify(gmm, data)

% [label, scores] = GMMclassify(gmm, data)
% 
% This function performs the classification of input data according to the
% GMM models.
% 
% gmm(i).class  - class ID
% gmm(i).obj    - object with the GMM model
% data          - input data matrix; columns are related to the features,
%                 rows to the observations
% 
% label         - column vector with numeric labels of the classified
%                 classes
% scores        - matrix containing the scores; each column is realted to
%                 one class

%% Paths and variables
scores = zeros(size(data,1), size(gmm,2));
label = zeros(size(data,1), 1);

%% Classify
for i = 1:size(data,1) % Over all observations
    for j = 1:size(gmm,2) % Over all classes
        scores(i,j) = pdf(gmm(j).obj, data(i,:));
    end
    
    [tmp, ind] = max(scores(i,:));
    label(i) = gmm(ind).class;
end