function [data, labels, labels_descr, features_descr] = convert_ndat_table(table)

% [data, labels, labels_descr, features_descr] = convert_ndat_table(table)
% 
% This function split the cell table generated by NDAT (Neurological
% Disorder Analysis Tool) into all necessary variables required by DCAT
% (Data Classification and Analysis Tool).
% 
% table             - the input cell table must have this format: 1st line 
%                     can be filled in ba an arbitrary information; 2nd
%                     line contains the class labels; 1st column contains
%                     the feature description
% 
% data              - input data matrix; columns are related to the 
%                     features, rows to the observations
% labels            - column vector with numeric labels of the observations
%                     (number of rows must be eaqual to the number of rows
%                     in data)
% labels_descr      - description of numeric labels
% features_descr    - description of labels

%% Extract the data matrix
data = cell2mat(table(3:end,2:end)).';

%% Extract the labels
lb = table(2,2:end).';
labels = zeros(length(lb),1);

labels_descr = unique(lb);

for i = 1:length(labels_descr)
    labels(ismember(lb, labels_descr(i))) = i;
end

%% Extract the features
features_descr = table(3:end,1);