function [l_data, l_descr] = limit_data(data, selected, descr)

% [l_data, l_descr] = limit_data(data, selected, descr)
% 
% This function limit the input data onlz to the selected features.
% 
% data      - input data matrix; columns are related to the features, rows
%             to the observations
% selected  - vector with selected IDs
% descr     - optional array or cell containing the feature description
% 
% l_data    - limited data matrix
% l_descr   - limited feature description

%% Paths and variables
if(max(selected) > size(data,2))
    error(['Maximum index to be selected is ' num2str(max(selected)) ...
        '. Number of columns of data matrix is ' num2str(size(data,2)) ...
        '.']);
end

if(min(selected) < 1)
    error('Minimum index to be selected cannot be lower than 1');
end

%% Sort and select onlz unique IDs
selected = unique(selected);

%% Limit the data to selected features
l_data = data(:,selected);

%% If neccesary limit also the feature description
if(nargin > 2)
    l_descr = descr(selected);
else
    l_descr = [];
end