function [nd_train, nd_test, mu, sigma] = normalize_data(d_train, d_test)

% [nd_train, nd_test, mu, sigma] = normalize_data(d_train, d_test)
% 
% This function z-normalize the input training matrix. If there are two
% inputs then the second matrix will be normalized according tu mean and
% standard deviation extracted from the first matrix.
% 
% d_train   - input training matrix; columns are related to the features,
%             rows to the observations
% d_test    - input testing matrix; columns are related to the features,
%             rows to the observations
% 
% nd_train  - z-normalized training matrix
% nd_test   - z-normalized testing matrix
% mu        - calculated mean
% sigma     - calculated standard deviation

%% Paths and variables
if(size(d_train,2) ~= size(d_test,2))
    error(['Input matrices ''d_train'' and ''d_test'' must have the ' ...
        'same number of columns.']);
end

%% Normalize the data
[nd_train, mu, sigma] = zscore(d_train);

if(nargin > 1)
    nd_test = (d_test - repmat(mu, size(d_test, 1), 1))./ ...
        repmat(sigma, size(d_test, 1), 1);
else
    nd_test = [];
end